==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebPaneDragOverEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebPaneDragActionDescriptionMetadata } from "./WebPaneDragActionDescriptionMetadata";
import { WebPaneDragOverEventArgsDetailDescription } from "./WebPaneDragOverEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebPaneDragOverEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneDragOverEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneDragOverEventArgsDetailDescriptionMetadata.a == null) {
                WebPaneDragOverEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneDragOverEventArgsDetailDescriptionMetadata.c(WebPaneDragOverEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebPaneDragOverEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPaneDragOverEventArgsDetailDescriptionMetadata.a);
            WebDockManagerPaneDescriptionMetadata.d(a);
            WebContentPaneDescriptionMetadata.d(a);
            WebPaneDragActionDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneDragOverEventArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__skipSuffix", "Boolean");
            a.item("SourcePane", "ExportedType:WebDockManagerPane");
            a.item("Panes", "Array:WebContentPaneDescription:ContentPane");
            a.item("Action", "ExportedType:WebPaneDragAction");
            a.item("IsValid", "Boolean");
        }
        static d(a) {
            WebPaneDragOverEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebPaneDragOverEventArgsDetail", () => new WebPaneDragOverEventArgsDetailDescription());
            a.ac("WebPaneDragOverEventArgsDetail", WebPaneDragOverEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebPaneDragOverEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneDragOverEventArgsDetailDescriptionMetadata, 'WebPaneDragOverEventArgsDetailDescriptionMetadata');
    WebPaneDragOverEventArgsDetailDescriptionMetadata.a = null;
    return WebPaneDragOverEventArgsDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebPaneDragOverEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneDragActionDescriptionMetadata } from "./WebPaneDragActionDescriptionMetadata";
import { WebPaneDragOverEventArgsDetailDescription } from "./WebPaneDragOverEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebPaneDragOverEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneDragOverEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneDragOverEventArgsDetailDescriptionMetadata.a == null) {
                WebPaneDragOverEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneDragOverEventArgsDetailDescriptionMetadata.c(WebPaneDragOverEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebPaneDragOverEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPaneDragOverEventArgsDetailDescriptionMetadata.a);
            WebDockManagerPaneDescriptionMetadata.d(a);
            WebPaneDragActionDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneDragOverEventArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("SourcePane", "ExportedType:WebDockManagerPane");
            a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
            a.item("Action", "ExportedType:WebPaneDragAction");
            a.item("IsValid", "Boolean");
        }
        static d(a) {
            WebPaneDragOverEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebPaneDragOverEventArgsDetail", () => new WebPaneDragOverEventArgsDetailDescription());
            a.ad("WebPaneDragOverEventArgsDetail", WebPaneDragOverEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebPaneDragOverEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneDragOverEventArgsDetailDescriptionMetadata, 'WebPaneDragOverEventArgsDetailDescriptionMetadata');
    WebPaneDragOverEventArgsDetailDescriptionMetadata.a = null;
    return WebPaneDragOverEventArgsDetailDescriptionMetadata;
})();
